@@ -16,30 +16,26 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerConsoleListener.cpp,v 1.11.2.3 2005/04/07 11:47:07 chpe Exp $
+ *  $Id: ErrorViewerConsoleListener.cpp,v 1.17 2006/05/10 18:14:57 chpe Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "error-viewer.h"
-
-#include "ErrorViewerConsoleListener.h"
-
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
-#include <nsCOMPtr.h>
-#include <nsMemory.h>
-
-#include <xpconnect/nsIScriptError.h>
-
-#include <glib/gi18n-lib.h>
-
 #include <string.h>
 
+#include <glib/gi18n-lib.h>
+
+#include <nsStringAPI.h>
+
+#include <nsCOMPtr.h>
+#include <nsMemory.h>
+#include <nsIScriptError.h>
+
 #include "ephy-debug.h"
+#include "error-viewer.h"
+
+#include "ErrorViewerConsoleListener.h"
 
 NS_IMPL_ISUPPORTS1(ErrorViewerConsoleListener, nsIConsoleListener)
 
@@ -64,20 +60,12 @@ ErrorViewerConsoleListener::GetMessageFromError (nsIScriptError *aError,
 	rv = aError->GetCategory (&category);
 	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && category, NS_ERROR_FAILURE);
 
-	nsEmbedString message;
-#ifdef MOZ_NSISCRIPTERROR_NSASTRING_
+	nsString message;
 	rv = aError->GetErrorMessage (message);
-#else
-	PRUnichar *msg = nsnull;
-	rv = aError->GetMessage (&msg);
-	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && msg, NS_ERROR_FAILURE);
-	message.Assign (msg);
-	nsMemory::Free (msg);
-#endif
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	nsEmbedCString cMessage;
-	NS_UTF16ToCString (nsEmbedString (message),
+	nsCString cMessage;
+	NS_UTF16ToCString (nsString (message),
 				NS_CSTRING_ENCODING_UTF8, cMessage);
 
 	/*
@@ -96,6 +84,7 @@ ErrorViewerConsoleListener::GetMessageFromError (nsIScriptError *aError,
 	 * "XUL Document" (nsXULDocument.cpp)
 	 * "ImageMap" (nsImageMap.cpp: has source line info)
 	 * "CSS Loader" (nsCSSLoader.cpp)
+	 * "XForms" (nsXFormsUtils.cpp)
 	 */
 	/* FIXME FIXME FIXME */
 	if (strstr (category, "javascript") == NULL &&
@@ -115,20 +104,20 @@ ErrorViewerConsoleListener::GetMessageFromError (nsIScriptError *aError,
 	rv = aError->GetLineNumber (&lineNumber);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-#ifdef MOZ_NSISCRIPTERROR_NSASTRING_
-	nsEmbedString sourceName;
+#ifdef HAVE_GECKO_1_8
+	nsString sourceName;
 	rv = aError->GetSourceName (sourceName);
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	nsEmbedCString cSourceName;
+	nsCString cSourceName;
 	NS_UTF16ToCString (sourceName, NS_CSTRING_ENCODING_UTF8, cSourceName);
 #else
 	PRUnichar *sourceName = nsnull;
 	rv = aError->GetSourceName (&sourceName);
 	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && sourceName, NS_ERROR_FAILURE);
 
-	nsEmbedCString cSourceName;
-	NS_UTF16ToCString (nsEmbedString (sourceName),
+	nsCString cSourceName;
+	NS_UTF16ToCString (nsString (sourceName),
 			   NS_CSTRING_ENCODING_UTF8, cSourceName);
 	nsMemory::Free (sourceName);
 #endif
@@ -166,8 +155,8 @@ NS_IMETHODIMP ErrorViewerConsoleListener::Observe(nsIConsoleMessage *aMessage)
 		rv = aMessage->GetMessage (&message);
 		NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && message, NS_ERROR_FAILURE);
 
-		nsEmbedCString cMessage;
-		NS_UTF16ToCString (nsEmbedString (message),
+		nsCString cMessage;
+		NS_UTF16ToCString (nsString (message),
 				   NS_CSTRING_ENCODING_UTF8, cMessage);
 
 		error_viewer_append (dialog, ERROR_VIEWER_ERROR, cMessage.get());
