@@ -15,33 +15,33 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.8.2.1 2005/04/07 11:47:07 chpe Exp $
+ *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.12 2006/09/03 16:31:12 chpe Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
+#include <glib/gi18n-lib.h>
+
+#include <nsStringAPI.h>
+
+#include <nsCOMPtr.h>
+#include <nsComponentManagerUtils.h>
+#include <nsIChannel.h>
+#include <nsIDOMHTMLAnchorElement.h>
+#include <nsIDOMHTMLAreaElement.h>
+#include <nsIDOMNode.h>
+#include <nsIURIChecker.h>
+#include <nsIURI.h>
+#include <nsNetError.h>
+#include <nsServiceManagerUtils.h>
+
+#include "EphyUtils.h"
+
 #include "link-checker.h"
 
 #include "ErrorViewerURICheckerObserver.h"
 
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
-#include <nsCOMPtr.h>
-#include <nsIChannel.h>
-#include <nsIDOMHTMLAnchorElement.h>
-#include <nsIDOMHTMLAreaElement.h>
-#include <nsIURI.h>
-#include <nsIServiceManager.h>
-
-#include <nsIURIChecker.h>
-#include <nsNetError.h>
-#include "EphyUtils.h"
-
-#include <glib/gi18n-lib.h>
-
 NS_IMPL_ISUPPORTS1(ErrorViewerURICheckerObserver, nsIRequestObserver)
 
 ErrorViewerURICheckerObserver::ErrorViewerURICheckerObserver()
@@ -57,14 +57,14 @@ ErrorViewerURICheckerObserver::~ErrorViewerURICheckerObserver()
 	{
 		char *msg, *part1, *part2;
 
-		part1 = g_strdup_printf ("Link check of %s complete",
+		part1 = g_strdup_printf ("Link check of “%s” complete",
 					 mFilename);
 		part2 = g_strdup_printf (ngettext ("Found %d invalid link",
 						   "Found %d invalid links",
 						   mNumLinksInvalid),
 					 mNumLinksInvalid);
 
-		msg = g_strconcat (part1, "\n", part2, NULL);
+		msg = g_strconcat (part1, "\n", part2, (char *) NULL);
 
 		link_checker_append (mChecker, ERROR_VIEWER_INFO, msg);
 
@@ -109,7 +109,7 @@ NS_IMETHODIMP ErrorViewerURICheckerObserver::OnStopRequest(nsIRequest *aRequest,
 	{
 		nsresult rv;
 
-		nsEmbedCString uri;
+		nsCString uri;
 		rv = aRequest->GetName(uri);
 		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
@@ -132,7 +132,7 @@ NS_IMETHODIMP ErrorViewerURICheckerObserver::OnStopRequest(nsIRequest *aRequest,
 nsresult ErrorViewerURICheckerObserver::AddNode (nsIDOMNode *node)
 {
 	nsresult rv;
-	nsEmbedString href;
+	nsString href;
 
 	nsCOMPtr<nsIDOMHTMLAnchorElement> anchor;
 	anchor = do_QueryInterface (node, &rv);
@@ -192,13 +192,13 @@ nsresult ErrorViewerURICheckerObserver::DoneAdding (void)
 
 	if (mNumLinksTotal == 0)
 	{
-		msg = g_strdup_printf ("No links to check on %s", mFilename);
+		msg = g_strdup_printf ("No links to check on “%s”", mFilename);
 	}
 	else
 	{
 		msg = g_strdup_printf
-		        (ngettext("Checking %d Link on %s",
-		                  "Checking %d Links on %s",
+		        (ngettext("Checking %d Link on “%s”",
+		                  "Checking %d Links on “%s”",
 		                  mNumLinksTotal),
 		         mNumLinksTotal, mFilename);
 	}
