@@ -16,10 +16,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-sample.cpp,v 1.1 2004/01/15 16:54:41 chpe Exp $
+ *  $Id: mozilla-sample.cpp,v 1.3 2006/05/10 18:14:59 chpe Exp $
  */
 
-#include "mozilla-sample.h"
+#include "mozilla-config.h"
+#include "config.h"
 
 #include <glib.h>
 
@@ -27,6 +28,8 @@
 #include <nsIDOMEvent.h>
 #include <nsIDOMMouseEvent.h>
 
+#include "mozilla-sample.h"
+
 void
 mozilla_do_something (gpointer dom_event)
 {
