@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sample-extension.c,v 1.3 2004/02/17 12:07:25 chpe Exp $
+ *  $Id: ephy-sample-extension.c,v 1.5 2005/01/28 22:30:17 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-sample-extension.h"
 #include "ephy-debug.h"
@@ -32,71 +30,26 @@
 
 #define EPHY_SAMPLE_EXTENSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SAMPLE_EXTENSION, EphySampleExtensionPrivate))
 
-struct EphySampleExtensionPrivate
+struct _EphySampleExtensionPrivate
 {
+	gpointer dummy;
 };
 
-static void ephy_sample_extension_class_init	(EphySampleExtensionClass *klass);
-static void ephy_sample_extension_iface_init	(EphyExtensionIface *iface);
-static void ephy_sample_extension_init		(EphySampleExtension *extension);
-
 enum
 {
 	PROP_0
 };
 
-static GObjectClass *sample_extension_parent_class = NULL;
+static GObjectClass *parent_class = NULL;
 
-static GType sample_extension_type = 0;
-
-GType
-ephy_sample_extension_get_type (void)
-{
-	return sample_extension_type;
-}
-
-GType
-ephy_sample_extension_register_type (GTypeModule *module)
-{
-	static const GTypeInfo our_info =
-	{
-		sizeof (EphySampleExtensionClass),
-		NULL, /* base_init */
-		NULL, /* base_finalize */
-		(GClassInitFunc) ephy_sample_extension_class_init,
-		NULL,
-		NULL, /* class_data */
-		sizeof (EphySampleExtension),
-		0, /* n_preallocs */
-		(GInstanceInitFunc) ephy_sample_extension_init
-	};
-
-	static const GInterfaceInfo extension_info =
-	{
-		(GInterfaceInitFunc) ephy_sample_extension_iface_init,
-		NULL,
-		NULL
-	};
-
-	sample_extension_type =
-		g_type_module_register_type (module,
-					     G_TYPE_OBJECT,
-					     "EphySampleExtension",
-					     &our_info, 0);
-
-	g_type_module_add_interface (module,
-				     sample_extension_type,
-				     EPHY_TYPE_EXTENSION,
-				     &extension_info);
-	return sample_extension_type;
-}
+static GType type = 0;
 
 static void
 ephy_sample_extension_init (EphySampleExtension *extension)
 {
 	extension->priv = EPHY_SAMPLE_EXTENSION_GET_PRIVATE (extension);
 
-	LOG ("EphySampleExtension initialising")
+	LOG ("EphySampleExtension initialising");
 }
 
 static void
@@ -105,9 +58,9 @@ ephy_sample_extension_finalize (GObject *object)
 /*
 	EphySampleExtension *extension = EPHY_SAMPLE_EXTENSION (object);
 */
-	LOG ("EphySampleExtension finalising")
+	LOG ("EphySampleExtension finalising");
 
-	G_OBJECT_CLASS (sample_extension_parent_class)->finalize (object);
+	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 static void
@@ -115,7 +68,7 @@ impl_attach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
 //	EphySampleExtension *extension = EPHY_SAMPLE_EXTENSION (ext);
-	LOG ("EphySampleExtension attach_window")
+	LOG ("EphySampleExtension attach_window");
 }
 
 static void
@@ -123,7 +76,23 @@ impl_detach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
 //	EphySampleExtension *extension = EPHY_SAMPLE_EXTENSION (ext);
-	LOG ("EphySampleExtension detach_window")
+	LOG ("EphySampleExtension detach_window");
+}
+
+static void
+impl_attach_tab (EphyExtension *ext,
+		 EphyWindow *window,
+		 EphyTab *tab)
+{
+	LOG ("attach_tab");
+}
+
+static void
+impl_detach_tab (EphyExtension *ext,
+		 EphyWindow *window,
+		 EphyTab *tab)
+{
+	LOG ("detach_tab");
 }
 
 static void
@@ -161,6 +130,8 @@ ephy_sample_extension_iface_init (EphyExtensionIface *iface)
 {
 	iface->attach_window = impl_attach_window;
 	iface->detach_window = impl_detach_window;
+	iface->attach_tab = impl_attach_tab;
+	iface->detach_tab = impl_detach_tab;
 }
 
 static void
@@ -168,7 +139,7 @@ ephy_sample_extension_class_init (EphySampleExtensionClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	sample_extension_parent_class = g_type_class_peek_parent (klass);
+	parent_class = g_type_class_peek_parent (klass);
 
 	object_class->finalize = ephy_sample_extension_finalize;
 	object_class->get_property = ephy_sample_extension_get_property;
@@ -176,3 +147,45 @@ ephy_sample_extension_class_init (EphySampleExtensionClass *klass)
 
 	g_type_class_add_private (object_class, sizeof (EphySampleExtensionPrivate));
 }
+
+GType
+ephy_sample_extension_get_type (void)
+{
+	return type;
+}
+
+GType
+ephy_sample_extension_register_type (GTypeModule *module)
+{
+	static const GTypeInfo our_info =
+	{
+		sizeof (EphySampleExtensionClass),
+		NULL, /* base_init */
+		NULL, /* base_finalize */
+		(GClassInitFunc) ephy_sample_extension_class_init,
+		NULL,
+		NULL, /* class_data */
+		sizeof (EphySampleExtension),
+		0, /* n_preallocs */
+		(GInstanceInitFunc) ephy_sample_extension_init
+	};
+
+	static const GInterfaceInfo extension_info =
+	{
+		(GInterfaceInitFunc) ephy_sample_extension_iface_init,
+		NULL,
+		NULL
+	};
+
+	type = g_type_module_register_type (module,
+					    G_TYPE_OBJECT,
+					    "EphySampleExtension",
+					    &our_info, 0);
+
+	g_type_module_add_interface (module,
+				     type,
+				     EPHY_TYPE_EXTENSION,
+				     &extension_info);
+
+	return type;
+}
