@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sidebar-commands.c,v 1.4 2005/09/19 14:05:46 chpe Exp $
+ *  $Id: sidebar-commands.c,v 1.5 2006/01/18 15:42:03 jframeau Exp $
  */
 
 #include "config.h"
@@ -88,7 +88,7 @@ save_property_url (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	if (event == NULL) return;
 
-	ephy_embed_event_get_property (event, property, &value);
+	value = ephy_embed_event_get_property (event, property);
 	location = g_value_get_string (value);
 
 	persist = EPHY_EMBED_PERSIST
