@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-grouper.c,v 1.6.6.1 2005/10/02 19:21:35 chpe Exp $
+ *  $Id: ephy-tab-grouper.c,v 1.9 2006/03/25 20:53:34 jframeau Exp $
  */
 
 #include "config.h"
@@ -83,19 +83,19 @@ ephy_tab_grouper_register_type (GTypeModule *module)
 /**
  * Clear the recently opened tab spot.
  */
-static gboolean
+static void
 reset_last_tab (EphyTabGrouper *grouper)
 {
-	grouper->priv->last_pos = -1;
+	EphyTabGrouperPrivate *priv = grouper->priv;
 
-	/* needed for tab-delete signal */
-	return FALSE;
+	priv->last_pos = -1;
 }
 
 static void
-tab_added_cb (EphyNotebook *notebook,
-	      EphyTab *tab,
-	      EphyTabGrouper *grouper)
+notebook_page_added_cb (GtkNotebook *notebook,
+			GtkWidget *tab,
+			guint page,
+			EphyTabGrouper *grouper)
 {
 	EphyTabGrouperPrivate *priv = grouper->priv;
 	int position;
@@ -107,32 +107,32 @@ tab_added_cb (EphyNotebook *notebook,
 	}
 	else
 	{
-		position = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)) + 1;
+		position = gtk_notebook_get_current_page (notebook) + 1;
 	}
 
-	ephy_notebook_move_tab (notebook, notebook, tab, position);
+	gtk_notebook_reorder_child (notebook, tab, position);
 
-	grouper->priv->last_pos = position;
+	priv->last_pos = position;
 }
 
 static void
 ephy_tab_grouper_set_notebook (EphyTabGrouper *grouper,
 			       GtkWidget *notebook)
 {
+	EphyTabGrouperPrivate *priv = grouper->priv;
+
 	g_return_if_fail (GTK_IS_NOTEBOOK (notebook));
 
-	grouper->priv->notebook = notebook;
+	priv->notebook = notebook;
 
 	/* Hook up the signals */
-	g_signal_connect (notebook, "tab_added", 
-			  G_CALLBACK (tab_added_cb), grouper);
-	g_signal_connect_swapped (notebook, "tab_removed", 
+	g_signal_connect (notebook, "page-added",
+			  G_CALLBACK (notebook_page_added_cb), grouper);
+	g_signal_connect_swapped (notebook, "page-removed", 
 				  G_CALLBACK (reset_last_tab), grouper);
-	g_signal_connect_swapped (notebook, "tab_detached", 
+	g_signal_connect_swapped (notebook, "page-reordered", 
 				  G_CALLBACK (reset_last_tab), grouper);
-	g_signal_connect_swapped (notebook, "switch_page", 
-				  G_CALLBACK (reset_last_tab), grouper);
-	g_signal_connect_swapped (notebook, "tabs_reordered", 
+	g_signal_connect_swapped (notebook, "switch-page", 
 				  G_CALLBACK (reset_last_tab), grouper);
 }
 
@@ -156,7 +156,7 @@ ephy_tab_grouper_finalize (GObject *object)
 
 	LOG ("EphyTabGrouper finalised");
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	parent_class->finalize (object);
 }
 
 static void
