@@ -15,19 +15,27 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyUtils.h,v 1.4 2005/03/02 14:01:30 chpe Exp $
+ *  $Id: EphyUtils.h,v 1.6 2006/07/16 12:59:01 chpe Exp $
  */
 
 #ifndef EPHY_UTILS_H
 #define EPHY_UTILS_H
 
-#include <nsIIOService.h>
-#include <nsIURI.h>
-#include <nsIDOMWindow.h>
+// cannot include EphyUtils with internal strings!
+#ifdef MOZILLA_INTERNAL_API
+#error Cannot use EphyUtils with MOZILLA_INTERNAL_API
+#endif
+
+#include <nscore.h>
+
 #include <gtk/gtkwidget.h>
 
-class nsIPrintSettings;
-struct _EmbedPrintInfo;
+class nsACString;
+class nsAString;
+class nsIDOMWindow;
+class nsIFile;
+class nsIIOService;
+class nsIURI;
 
 namespace EphyUtils
 {
@@ -43,13 +51,19 @@ namespace EphyUtils
 						 const char *charset = nsnull,
 						 nsIURI *baseURI = nsnull);
 
+	nsresult	NewFileURI		(nsIURI **result,
+						 nsIFile *spec);
+
 	GtkWidget      *FindEmbed		(nsIDOMWindow *aDOMWindow);
 
 	GtkWidget      *FindGtkParent		(nsIDOMWindow *aDOMWindow);
+	
+	char *		ConvertUTF16toUTF8	(const PRUnichar*, PRInt32);
+}
 
-	nsresult        CollatePrintSettings	(const _EmbedPrintInfo *info,
-						 nsIPrintSettings *settings,
-						 gboolean preview);
+namespace EphyJSUtils
+{
+	PRBool IsCalledFromScript ();
 }
 
 #endif
